manhattan users
===============

Chains and factories for building user access / control functionality into a manhattan manage application.

How to install
--------------

`pip install manhattan_users`
